@@ -16,9 +16,6 @@ import requests
 # only required for certain code paths that go beyond core routines.
 # e.g., get_snapshot_cam(dformat='array')
 
-# inline: paramiko
-# only required by Instance class
-
 
 class Error(Exception):
     """Error not otherwise specified
@@ -183,6 +180,7 @@ class APIClient(object):  # pylint: disable=too-many-public-methods
             params['maxlen'] = maxlen
         if types is not None:
             params['types'] = ','.join(types)
+        params['info'] = 't'
         res = requests.get(self.__base_uri + '/deployments', params=params, headers=self.__headers, verify=self.__verify_certs)
         if res.ok:
             payload = res.json()
@@ -191,10 +189,11 @@ class APIClient(object):  # pylint: disable=too-many-public-methods
         page_count = payload.get('page_count', None)
         wdeployments = []
         for wdeployment in payload['workspace_deployments']:
-            payload = self.get_wdeployment_info(wdeployment)
             wdeployments.append({
                 'id': wdeployment,
-                'type': payload['type'],
+                'type': payload['info'][wdeployment]['type'],
+                'region': payload['info'][wdeployment]['region'],
+                'queuelen': payload['info'][wdeployment]['queuelen'],
             })
         if max_per_page is None:
             return wdeployments
