@@ -236,7 +236,7 @@ def add_cli_create_ci_project(subparsers):
 def add_cli_submit_ci_job(subparsers):
     """Create subparser for `submit-ci-job`.
     """
-    desc = 'create a CI project for this user.'
+    desc = 'submit a CI job.'
     ci_submit_job_parser = subparsers.add_parser('submit-ci-job', description=desc, help=desc, add_help=False)
     ci_submit_job_parser.add_argument('--repo-branch', metavar='BRANCH', dest='repo_branch',
                                       default=None,
@@ -507,10 +507,11 @@ def cli_addon_cam(apic, args):
     if payload['status'] != 'active' or not snapshot_payload['success']:
         raise Exception('timed out waiting for `cam` add-on to become active')
     if args.output_file:
-        fp = open(args.output_file, 'wb')
+        with open(args.output_file, 'wb') as fp:
+            fp.write(snapshot_payload['data'])
     else:
         fp = os.fdopen(1, 'wb')
-    fp.write(snapshot_payload['data'])
+        fp.write(snapshot_payload['data'])
     return 0
 
 
